#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-9EJoWIhD6rI2D8tpdtw5RF
key:                  lsp-2.2.0.0-9EJoWIhD6rI2D8tpdtw5RF
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  f3b762bba0f9a9bd498bad2371d05a13
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-HgpVsxXVwzUAL0UBBsxEKQ:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-HgpVsxXVwzUAL0UBBsxEKQ:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-HgpVsxXVwzUAL0UBBsxEKQ:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-HgpVsxXVwzUAL0UBBsxEKQ:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-9EJoWIhD6rI2D8tpdtw5RF
depends:
    aeson-2.2.1.0-LCgCxr5fZ2fF779OJkJoWg
    async-2.2.5-4DIIy34WjVcL8AkZ9wmUb5
    attoparsec-0.14.4-5VjG494kZnAHtf5YQc6bBX base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-Hh0B9YJs2O69wRZEHl8awe
    containers-0.6.7 data-default-0.7.1.3-16enERVyZGuFmPxHvERcmd
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-8DiXdwI1HyoGIpw8Heqw3G
    lens-5.3.4-EMehBwckpg97FXX4cpVrvv
    lens-aeson-1.2.3-C1l3R2n4VGMGemKkCwMTmb
    lsp-types-2.0.2.0-HgpVsxXVwzUAL0UBBsxEKQ mtl-2.3.1
    prettyprinter-1.7.1-eZs6LtbK8M8wXnTmHvu32
    random-1.2.1.3-6vcHOvK2uEB1wXqnxBIn5Y
    row-types-1.0.1.2-L0uu6x7HHtJ9wcPcmwl03Z
    sorted-list-0.2.3.1-3eRJU7Chi1e1t3NxcmBdBR stm-2.5.1.0
    temporary-1.3-CG8QkCzKAH68Yts0313xeR text-2.0.2
    text-rope-0.3-D8FYpvSLMW4FffQJOlPBxU transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-LFprVvrjTX4JVFniJRp7e6
    uuid-1.3.16-8PLS3U9MzfvCHukHLZ9xyd

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

